import { jsx as _jsx } from "react/jsx-runtime";
import { vitest } from 'vitest';
import { screen } from '@testing-library/react';
import { ManagerText } from './ManagerText';
import { render } from '../../utils/test.provider';
import fr_FR from './translations/Messages_fr_FR.json';
import { useAuthorizationIam } from '../../hooks/iam';
vitest.mock('../../hooks/iam');
const renderComponent = (props) => {
    return render(_jsx(ManagerText, { ...props }));
};
const mockedHook = useAuthorizationIam;
describe('ManagerText tests', () => {
    afterEach(() => {
        vitest.resetAllMocks();
    });
    describe('should display manager text', () => {
        it('with true value for useAuthorizationIam', () => {
            mockedHook.mockReturnValue({
                isAuthorized: true,
                isLoading: true,
                isFetched: true,
            });
            renderComponent({
                urn: 'urn:v9:eu:resource:manager-react-components:vrz-a878-dsflkds-fdsfsd',
                iamActions: [
                    'manager-react-components:apiovh:manager-react-components/get-display',
                ],
                children: _jsx("div", { children: "foo-manager-text" }),
            });
            expect(screen.getAllByText('foo-manager-text')).not.toBeNull();
        });
    });
    describe('should display error manager text', () => {
        it('with false value for useAuthorizationIam', () => {
            mockedHook.mockReturnValue({
                isAuthorized: false,
                isLoading: true,
                isFetched: true,
            });
            renderComponent({
                urn: 'urn:v9:eu:resource:manager-react-components:vrz-a878-dsflkds-fdsfsd',
                iamActions: [
                    'manager-react-components:apiovh:manager-react-components/get-display',
                ],
                children: _jsx("div", { children: "foo-manager-text" }),
            });
            expect(screen.findByText(fr_FR.iam_hidden_text)).not.toBeNull();
        });
    });
});
