import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { useEffect, useState } from 'react';
import { useMedia } from 'react-use';
import { clsx } from 'clsx';
import { v4 as uuidV4 } from 'uuid';
import { OdsIcon, OdsText } from '@ovhcloud/ods-components/react';
import { ODS_ICON_NAME } from '@ovhcloud/ods-components';
import { hashCode } from '../../../utils';
export function TabsComponent({ id = uuidV4(), items = [], itemKey, titleElement = (item) => _jsx("div", { children: `title ${item}` }), contentElement = (item) => _jsx("div", { children: `content ${item}` }), mobileBreakPoint, className, onChange, }) {
    const [state, setState] = useState({
        items,
        selectedItem: items?.[0],
    });
    const setSelectedItem = (item) => {
        setState((prev) => ({
            ...prev,
            selectedItem: item,
        }));
    };
    const uniqKey = (item) => itemKey ? itemKey(item) : `${hashCode(item)}`;
    useEffect(() => {
        if (Array.isArray(items) &&
            items.length &&
            (items.length !== state.items.length ||
                items.some((item, index) => !Object.is(item, state.items[index])))) {
            setState(() => ({
                items,
                selectedItem: items[0],
            }));
        }
    }, [items]);
    useEffect(() => {
        if (typeof onChange === 'function') {
            onChange(state.selectedItem);
        }
    }, [state.selectedItem]);
    const isDesktop = useMedia(`(min-width: ${mobileBreakPoint || 760}px)`);
    return (_jsx(_Fragment, { children: isDesktop ? (_jsxs("section", { className: clsx('rounded-sm flex flex-col', className), "data-testid": "desktop", children: [_jsxs("ul", { className: "flex flex-row list-none p-0 m-0 w-full", "data-testid": "titles", children: [state.items.map((item) => (_jsx("li", { className: clsx('px-4 py-4 cursor-pointer border border-solid border-[--ods-color-primary-100] rounded-t-lg', item === state.selectedItem
                                ? 'border-b-0 bg-[--ods-color-primary-050]'
                                : 'border-b bg-white'), children: _jsx("button", { className: "border-0 bg-transparent cursor-pointer w-full", onClick: () => setSelectedItem(item), onKeyDown: () => setSelectedItem(item), children: titleElement(item, item === state.selectedItem) }) }, `tabs-${id}title-${uniqKey(item)}`))), _jsx("li", { className: "border-0 border-b border-solid border-b-[--ods-color-primary-100] w-full" }, 'none')] }), _jsx("div", { className: "bg-[--ods-color-primary-050] border border-solid border-[--ods-color-primary-100] border-t-0", children: contentElement(state.selectedItem) })] })) : (_jsx("section", { className: clsx('grid gap-6 grid-cols-1', className), "data-testid": "mobile", children: state.items.map((item) => (_jsxs("div", { className: "px-2 bg-[--ods-color-primary-050] border border-solid border-[--ods-color-primary-100] rounded-lg", children: [_jsxs("button", { className: "flex cursor-pointer px-4 py-4 w-full border-0 bg-transparent", onClick: () => setSelectedItem(item), onKeyDown: () => setSelectedItem(item), children: [_jsx("div", { className: "w-full", children: _jsx(OdsText, { children: titleElement(item, item === state.selectedItem) }) }), _jsx("div", { className: "w-fit flex items-center", children: !Object.is(state.selectedItem, item) ? (_jsx(OdsIcon, { name: ODS_ICON_NAME.chevronDown })) : (_jsx(OdsIcon, { name: ODS_ICON_NAME.chevronUp })) })] }), Object.is(state.selectedItem, item) && (_jsx("div", { children: contentElement(item) }))] }, `tabs-${id}title-${uniqKey(item)}`))) })) }));
}
export default TabsComponent;
