import { jsx as _jsx, jsxs as _jsxs, Fragment as _Fragment } from "react/jsx-runtime";
import { useTranslation } from 'react-i18next';
import { OdsText } from '@ovhcloud/ods-components/react';
import { IntervalUnitType } from '../../../enumTypes';
import { getPrice, convertIntervalPrice, getPriceTextFormatted, } from './price.utils';
import './translations/translations';
const TextPriceContent = ({ children, }) => _jsx("span", { className: "ml-1", children: children });
export function Price({ value, intervalUnit, tax, ovhSubsidiary, locale, isConvertIntervalUnit, }) {
    const { t } = useTranslation('price');
    const isAsiaFormat = ['ASIA', 'AU', 'IN', 'SG'].includes(ovhSubsidiary);
    const isGermanFormat = ['DE', 'FI', 'SN'].includes(ovhSubsidiary);
    const isFrenchFormat = [
        'CZ',
        'ES',
        'FR',
        'GB',
        'IE',
        'IT',
        'LT',
        'MA',
        'NL',
        'PL',
        'PT',
        'TN',
    ].includes(ovhSubsidiary);
    const isUSFormat = ['CA', 'QC', 'US', 'WE', 'WS'].includes(ovhSubsidiary);
    const convertedValue = isConvertIntervalUnit
        ? convertIntervalPrice(value, intervalUnit)
        : value;
    const convertedTax = isConvertIntervalUnit
        ? convertIntervalPrice(tax || 0, intervalUnit)
        : tax || 0;
    const priceWithoutTax = getPriceTextFormatted(ovhSubsidiary, locale, getPrice(convertedValue));
    const priceWithTax = getPriceTextFormatted(ovhSubsidiary, locale, getPrice(convertedValue, convertedTax));
    const intervalUnitText = intervalUnit && intervalUnit !== IntervalUnitType.none
        ? t(`price_per_${intervalUnit}`)
        : '';
    const components = [
        {
            condition: value === 0,
            component: _jsx("span", { children: t('price_free') }),
        },
        {
            condition: isFrenchFormat && tax > 0,
            component: (_jsxs(_Fragment, { children: [_jsx("span", { className: "mr-1 text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: priceWithoutTax }), _jsx("span", { className: "text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: t('price_ht_label') }), _jsx("span", { className: "ml-1 text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: intervalUnitText }), _jsxs(TextPriceContent, { children: [_jsxs("span", { className: "text-[--ods-color-neutral-500] text-[14px] leading-[18px] font-semibold", children: ["(", priceWithTax] }), _jsxs("span", { className: "ml-1 text-[--ods-color-neutral-500] text-[14px] leading-[18px] font-semibold", children: [t('price_ttc_label'), ")"] })] })] })),
        },
        {
            condition: isFrenchFormat && !tax,
            component: (_jsxs(_Fragment, { children: [_jsx("span", { className: "mr-1 text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: priceWithoutTax }), _jsx("span", { className: "text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: t('price_ht_label') }), _jsx("span", { className: "ml-1 text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: intervalUnitText })] })),
        },
        {
            condition: isGermanFormat && tax > 0,
            component: (_jsxs(_Fragment, { children: [_jsx("span", { className: "mr-1 text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: priceWithTax }), _jsx("span", { className: "ml-1 text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: intervalUnitText })] })),
        },
        {
            condition: isAsiaFormat && (!tax || tax === 0),
            component: (_jsxs(_Fragment, { children: [_jsx("span", { className: "mr-1 text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: priceWithoutTax }), _jsx("span", { className: "text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: t('price_gst_excl_label') }), _jsx("span", { className: "ml-1 text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: intervalUnitText })] })),
        },
        {
            condition: isAsiaFormat,
            component: (_jsxs(_Fragment, { children: [_jsx("span", { className: "mr-1 text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: priceWithoutTax }), _jsx("span", { className: "text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: t('price_gst_excl_label') }), _jsx("span", { className: "ml-1 text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: intervalUnitText }), _jsxs(TextPriceContent, { children: [_jsxs("span", { className: "text-[--ods-color-neutral-500] text-[14px] leading-[18px] font-semibold", children: ["(", priceWithTax] }), _jsxs("span", { className: "ml-1 text-[--ods-color-neutral-500] text-[14px] leading-[18px] font-semibold", children: [t('price_gst_incl_label'), ")"] })] })] })),
        },
        {
            condition: isUSFormat,
            component: (_jsxs(_Fragment, { children: [_jsx("span", { className: "mr-1 text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: priceWithoutTax }), _jsx("span", { className: "ml-1 text-[--ods-color-text] text-[16px] leading-[20px] font-semibold", children: intervalUnitText })] })),
        },
    ];
    const matchingComponent = components.find(({ condition }) => condition);
    if (!matchingComponent) {
        return _jsx(_Fragment, {});
    }
    return _jsx(OdsText, { children: matchingComponent.component });
}
export default Price;
