import { Fragment as _Fragment, jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { flexRender, getCoreRowModel, useReactTable, getSortedRowModel, } from '@tanstack/react-table';
import { ODS_ICON_NAME, ODS_BUTTON_VARIANT } from '@ovhcloud/ods-components';
import { OdsButton, OdsIcon, OdsPagination, OdsTable, } from '@ovhcloud/ods-components/react';
import { useTranslation } from 'react-i18next';
import { DataGridTextCell } from './text-cell.component';
import './translations';
export const Datagrid = ({ columns, items, totalItems, pagination, sorting, className, onPaginationChange, onSortChange, contentAlignLeft = true, hasNextPage, onFetchNextPage, manualSorting = true, manualPagination = true, noResultLabel, }) => {
    const { t } = useTranslation('datagrid');
    const pageCount = pagination
        ? Math.ceil(totalItems / pagination.pageSize)
        : 1;
    const table = useReactTable({
        columns: columns.map((col) => ({
            accessorKey: col.id,
            cell: (props) => col.cell(props.row.original),
            header: col.label,
            enableSorting: col.isSortable !== false,
        })),
        data: items,
        manualPagination,
        manualSorting,
        enableSortingRemoval: false,
        sortDescFirst: false,
        getCoreRowModel: getCoreRowModel(),
        pageCount,
        ...(!manualSorting && {
            onSortingChange: onSortChange,
            state: {
                sorting,
            },
            getSortedRowModel: getSortedRowModel(),
        }),
        ...(manualSorting && {
            state: {
                ...(sorting && {
                    sorting: [sorting],
                }),
            },
            onStateChange: (updater) => {
                if (typeof updater === 'function') {
                    const state = updater({ ...table.getState(), ...sorting });
                    if (onSortChange)
                        onSortChange(state.sorting[0]);
                }
                else if (onSortChange) {
                    onSortChange(updater.sorting[0]);
                }
            },
        }),
    });
    return (_jsxs("div", { children: [_jsx("div", { className: `contents px-[1px] ${className || ''}`, children: _jsx(OdsTable, { className: "overflow-x-visible", children: _jsxs("table", { className: "w-full border-collapse", children: [_jsx("thead", { children: table.getHeaderGroups().map((headerGroup) => (_jsx("tr", { children: headerGroup.headers.map((header) => (_jsx("th", { className: `${contentAlignLeft ? 'text-left pl-4' : 'text-center'} h-11 whitespace-nowrap `, children: header.isPlaceholder ? null : (_jsxs("div", { ...{
                                                className: onSortChange && header.column.getCanSort()
                                                    ? 'cursor-pointer select-none'
                                                    : '',
                                                ...(onSortChange && {
                                                    onClick: header.column.getToggleSortingHandler(),
                                                }),
                                            }, "data-testid": `header-${header.id}`, children: [_jsx("span", { children: _jsx(_Fragment, { children: flexRender(header.column.columnDef.header, header.getContext()) }) }), _jsx("span", { className: `align-middle inline-block h-4 -mt-6`, children: _jsx(OdsIcon, { className: header.column.getIsSorted() ? '' : 'invisible', name: header.column.getIsSorted() ===
                                                            'asc'
                                                            ? ODS_ICON_NAME.arrowUp
                                                            : ODS_ICON_NAME.arrowDown }) })] })) }, header.id))) }, headerGroup.id))) }), _jsxs("tbody", { children: [table.getRowModel().rows.map((row) => (_jsx("tr", { className: "border-solid border-[1px] h-[3.25rem] border-[--ods-color-blue-200]", children: row.getVisibleCells().map((cell) => (_jsx("td", { className: contentAlignLeft ? 'text-left pl-4' : 'text-center', children: flexRender(cell.column.columnDef.cell, cell.getContext()) }, cell.id))) }, row.id))), table.getRowModel().rows.length === 0 && (_jsx("tr", { className: 'border-solid border-[1px] h-[3.25rem] border-[--ods-color-blue-200]', children: _jsx("td", { className: "text-center", colSpan: columns.length, children: _jsx(DataGridTextCell, { children: noResultLabel ?? t('common_pagination_no_results') }) }) }))] })] }) }) }), !onFetchNextPage && items?.length > 0 && pagination ? (_jsxs(OdsPagination, { defaultCurrentPage: pagination.pageIndex + 1, className: 'flex xs:justify-start md:justify-end', "total-items": totalItems, "total-pages": pageCount, "default-items-per-page": pagination.pageSize, onOdsChange: ({ detail }) => {
                    if (detail.current !== detail.oldCurrent) {
                        onPaginationChange({
                            ...pagination,
                            pageIndex: detail.current - 1,
                            pageSize: detail.itemPerPage,
                        });
                    }
                }, onOdsItemPerPageChange: ({ detail }) => {
                    if (detail.current !== pagination.pageSize)
                        onPaginationChange({
                            ...pagination,
                            pageSize: detail.current,
                            pageIndex: 0,
                        });
                }, children: [_jsx("span", { slot: "before-total-items", className: "mr-3", children: t('common_pagination_of') }), _jsx("span", { slot: "after-total-items", className: "ml-3", children: t('common_pagination_results') })] })) : (_jsx(_Fragment, {})), hasNextPage && (_jsx("div", { className: "grid justify-items-center my-5", children: _jsx(OdsButton, { variant: ODS_BUTTON_VARIANT.outline, label: t('common_pagination_load_more'), onClick: onFetchNextPage }) }))] }));
};
