import { jsx as _jsx } from "react/jsx-runtime";
import { vitest } from 'vitest';
import { act } from '@testing-library/react';
import { FilterList } from './filter-list.component';
import { render } from '../../utils/test.provider';
const renderComponent = (props) => {
    return render(_jsx(FilterList, { ...props }));
};
describe('FilterList tests', () => {
    it('should not display tags when the filters props is empty', () => {
        const propsWithEmptyFilters = {
            filters: [],
            onRemoveFilter: vitest.fn(),
        };
        const { container } = renderComponent(propsWithEmptyFilters);
        expect(container).toBeEmptyDOMElement();
    });
    it('should display 1 tag when the filters array props have one element', () => {
        const propsWithOneFiltersItem = {
            filters: [
                {
                    key: 'username',
                    comparator: 'includes',
                    value: 'temp_user',
                    label: "Nom d'utilisateur",
                },
            ],
            onRemoveFilter: vitest.fn(),
        };
        const { container, getAllByTestId } = renderComponent(propsWithOneFiltersItem);
        const filterChipItems = getAllByTestId('filter-list_tag_item');
        expect(container).not.toBeEmptyDOMElement();
        expect(filterChipItems).toHaveLength(1);
    });
    it('should display 2 tags when the filters array props have two elements', () => {
        const propsWithTwoFiltersItem = {
            filters: [
                {
                    key: 'username',
                    comparator: 'includes',
                    value: 'random_user',
                    label: "Nom d'utilisateur",
                },
                {
                    key: 'username',
                    comparator: 'includes',
                    value: 'temp_user',
                    label: "Nom d'utilisateur",
                },
            ],
            onRemoveFilter: vitest.fn(),
        };
        const { container, getAllByTestId } = renderComponent(propsWithTwoFiltersItem);
        const filterChipItems = getAllByTestId('filter-list_tag_item');
        expect(container).not.toBeEmptyDOMElement();
        expect(filterChipItems).toHaveLength(2);
    });
    it('should call onRemoveFilter function when the chip cross is clicked', () => {
        const mockOnRemoveFilter = vitest.fn();
        const propsWithOneFiltersItem = {
            filters: [
                {
                    key: 'username',
                    comparator: 'includes',
                    value: 'temp_user',
                    label: "Nom d'utilisateur",
                },
            ],
            onRemoveFilter: mockOnRemoveFilter,
        };
        const { getByTestId } = renderComponent(propsWithOneFiltersItem);
        const filterChipItem = getByTestId('filter-list_tag_item');
        act(() => {
            filterChipItem.onClick();
        });
        expect(mockOnRemoveFilter).toHaveBeenNthCalledWith(1, {
            comparator: 'includes',
            key: 'username',
            label: "Nom d'utilisateur",
            value: 'temp_user',
        });
    });
});
