import { jsx as _jsx, Fragment as _Fragment, jsxs as _jsxs } from "react/jsx-runtime";
import { useCallback, useEffect, useState } from 'react';
import { OdsCard } from '@ovhcloud/ods-components/react';
import { clsx } from 'clsx';
import isEqual from 'lodash.isequal';
import { hashCode } from '../../../../utils';
const uniqBy = function uniqBy(items, cb) {
    return [
        ...items
            .reduce((map, item) => {
            if (!map.has(cb(item)))
                map.set(cb(item), item);
            return map;
        }, new Map())
            .values(),
    ];
};
const stackItems = function stackItems(items, cb) {
    const stacks = new Map();
    if (cb) {
        const uniques = uniqBy(items, cb);
        uniques.forEach((unique) => {
            const key = cb(unique);
            stacks.set(key, []);
            stacks.get(key).push(...items.filter((item) => isEqual(key, cb(item))));
        });
    }
    else {
        stacks.set(undefined, items);
    }
    return stacks;
};
export const SimpleTilesInputComponent = function SimpleTilesInputComponent({ items, value, onInput, label, tileClass, stack, id, }) {
    const [state, setState] = useState({
        stacks: stackItems(items, stack?.by),
        selectedStack: stack?.value,
        activeClass: `cursor-pointer font-bold bg-[--ods-color-blue-100] border-[--ods-color-blue-600] ${tileClass?.active}`,
        inactiveClass: `cursor-pointer border-[--ods-color-blue-100] hover:bg-[--ods-color-blue-100] hover:border-[--ods-color-blue-600] ${tileClass?.inactive}`,
    });
    const set = {
        selectedStack: (s) => {
            setState((prev) => ({ ...prev, selectedStack: s }));
        },
        value: (t) => onInput(t),
    };
    const is = {
        stack: {
            checked: useCallback((s) => state.stacks?.get(s)?.length > 1
                ? isEqual(state.selectedStack, s)
                : isEqual(state.stacks.get(s)[0], value), [state.stacks, state.selectedStack, value]),
            singleton: useCallback((s) => state.stacks.get(s)?.length === 1, [state.stacks]),
        },
    };
    // Update stacks from props
    useEffect(() => {
        setState((prev) => ({ ...prev, stacks: stackItems(items, stack?.by) }));
    }, [items, stack]);
    // Update active/inactive class from props
    useEffect(() => {
        if (tileClass) {
            setState((prev) => ({
                ...prev,
                activeClass: `cursor-pointer font-bold bg-[--ods-color-blue-100] border-[--ods-color-blue-600] ${tileClass?.active}`,
                inactiveClass: `cursor-pointer border-[--ods-color-blue-100] hover:bg-[--ods-color-blue-100] hover:border-[--ods-color-blue-600] ${tileClass?.inactive}`,
            }));
        }
    }, [tileClass]);
    // Warn parent on stack change
    useEffect(() => {
        if (typeof stack?.onChange === 'function') {
            stack.onChange(state.selectedStack);
        }
    }, [state.selectedStack]);
    // Update selected stack from value
    useEffect(() => {
        if (stack) {
            set.selectedStack(value ? stack.by(value) : undefined);
        }
    }, [value]);
    // Update value from selected stack
    useEffect(() => {
        if (stack &&
            state.stacks.get(state.selectedStack)?.length &&
            !isEqual(state.selectedStack, stack.by(value))) {
            set.value(state.stacks.get(state.selectedStack)[0]);
        }
    }, [state.selectedStack]);
    return (_jsxs("div", { id: typeof id === 'function' ? id() : id, children: [_jsx("ul", { className: "simple-tiles-input-ul grid gap-6 list-none p-6 m-0 grid-cols-1 md:grid-cols-3", children: stack
                    ? [...state.stacks.keys()].map((key) => (_jsx("li", { className: "w-full px-1", children: _jsx(OdsCard, { onClick: () => is.stack.singleton(key)
                                ? set.value(state.stacks.get(key)[0])
                                : set.selectedStack(key), className: `${clsx(is.stack.checked(key)
                                ? state.activeClass
                                : state.inactiveClass)} w-full px-[24px] py-[16px]`, children: is.stack.singleton(key)
                                ? label(state.stacks.get(key)[0])
                                : stack?.label(key, state.stacks.get(key)) }) }, hashCode(key))))
                    : items.map((item) => (_jsx("li", { className: "w-full px-1", children: _jsx(OdsCard, { onClick: () => set.value(item), className: `${clsx(isEqual(value, item)
                                ? state.activeClass
                                : state.inactiveClass)} w-full px-[24px] py-[16px]`, children: label(item) }) }, hashCode(item)))) }), state.selectedStack &&
                state.stacks.get(state.selectedStack)?.length > 1 && (_jsxs(_Fragment, { children: [_jsx("div", { className: "mt-6 ml-8", children: _jsx("span", { className: "text-[--ods-color-heading] leading-[22px] font-bold", children: stack.title(state.selectedStack, state.stacks.get(state.selectedStack)) }) }), _jsx(SimpleTilesInputComponent, { value: value, items: state.stacks.get(state.selectedStack), label: label, onInput: onInput, tileClass: tileClass })] }))] }));
};
