import { jsx as _jsx } from "react/jsx-runtime";
import { vitest } from 'vitest';
import { waitFor, screen, fireEvent } from '@testing-library/react';
import { ODS_ICON_NAME } from '@ovhcloud/ods-components';
import { ActionMenu } from './action.component';
import { render } from '../../../../utils/test.provider';
import { useAuthorizationIam } from '../../../../hooks/iam';
vitest.mock('../../../../hooks/iam');
const actionItems = {
    id: 'action-menu-test-id',
    items: [
        {
            id: 1,
            onClick: () => window.open('/'),
            label: 'Action 1',
            urn: 'urn:v18:eu:resource:m--components:vrz-a878-dsflkds-fdsfdsfdsf',
            iamActions: ['vrackServices:apiovh:iam/resource/tag/remove'],
        },
        {
            id: 2,
            onClick: () => window.open('/'),
            label: 'Action 2',
            urn: 'urn:v18:eu:resource:m--components:vrz-a878-dsflkds-fdsfdsfdsf',
            iamActions: ['vrackServices:apiovh:iam/resource/tag/remove'],
        },
    ],
};
const setupSpecTest = async (customProps) => waitFor(() => render(_jsx(ActionMenu, { ...actionItems, ...customProps })));
const mockedHook = useAuthorizationIam;
describe('ActionMenu', () => {
    it('renders menu actions correctly', async () => {
        mockedHook.mockReturnValue({
            isAuthorized: true,
            isLoading: true,
            isFetched: true,
        });
        await setupSpecTest();
        const actionMenuIcon = screen.getByTestId('navigation-action-trigger-action');
        fireEvent.click(actionMenuIcon);
        // Wait for the button text to update
        await waitFor(() => {
            const action1 = screen.getAllByTestId('manager-button')[0];
            const action2 = screen.getAllByTestId('manager-button')[1];
            expect(action1).toBeInTheDocument();
            expect(action2).toBeInTheDocument();
            expect(actionMenuIcon.getAttribute('icon')).toBe('chevron-down');
        });
    });
    it('renders compact menu with classic ellipsis correctly', async () => {
        await setupSpecTest({ isCompact: true });
        const actionMenuIcon = screen.getByTestId('navigation-action-trigger-action');
        expect(actionMenuIcon.getAttribute('icon')).toBe('ellipsis-vertical');
    });
    it('renders compact menu with custom icon menu correctly', async () => {
        await setupSpecTest({
            icon: ODS_ICON_NAME.ellipsisHorizontal,
        });
        const actionMenuIcon = screen.getByTestId('navigation-action-trigger-action');
        expect(actionMenuIcon.getAttribute('icon')).toBe('ellipsis-horizontal');
    });
});
