import { create } from 'zustand';
export var NotificationType;
(function (NotificationType) {
    NotificationType["Success"] = "success";
    NotificationType["Error"] = "error";
    NotificationType["Info"] = "info";
    NotificationType["Warning"] = "warning";
})(NotificationType || (NotificationType = {}));
export const NOTIFICATION_MINIMAL_DISPLAY_TIME = 1000;
export const useNotifications = create((set, get) => ({
    uid: 0,
    notifications: [],
    addNotification: (content, type, dismissable = false) => set((state) => ({
        uid: state.uid + 1,
        notifications: [
            ...state.notifications,
            {
                uid: state.uid,
                content,
                type,
                dismissable,
                creationTimestamp: Date.now(),
            },
        ],
    })),
    addSuccess: (content, dismissable = false) => get().addNotification(content, NotificationType.Success, dismissable),
    addError: (content, dismissable = false) => get().addNotification(content, NotificationType.Error, dismissable),
    addWarning: (content, dismissable = false) => get().addNotification(content, NotificationType.Warning, dismissable),
    addInfo: (content, dismissable = false) => get().addNotification(content, NotificationType.Info, dismissable),
    clearNotification: (toRemoveUid) => set((state) => ({
        notifications: state.notifications.filter(({ uid }) => uid !== toRemoveUid),
    })),
    clearNotifications: () => set((state) => ({
        notifications: state.notifications.filter((notification) => Date.now() - notification.creationTimestamp <
            NOTIFICATION_MINIMAL_DISPLAY_TIME),
    })),
}));
export default useNotifications;
