import { jsx as _jsx } from "react/jsx-runtime";
import { vi } from 'vitest';
import { render, screen } from '@testing-library/react';
import { Navigate } from 'react-router-dom';
import { RedirectionGuard } from './redirection-guard.component';
import '@testing-library/jest-dom';
vi.mock('react-router-dom', () => ({
    Navigate: vi.fn(() => null),
}));
describe('RedirectionGuard', () => {
    beforeEach(() => {
        vi.resetAllMocks();
    });
    it('should render children when condition is false', () => {
        render(_jsx(RedirectionGuard, { condition: false, isLoading: false, route: "/test", children: _jsx("div", { children: "Test Child" }) }));
        expect(screen.getByText('Test Child')).toBeInTheDocument();
        expect(Navigate).not.toHaveBeenCalled();
    });
    it('should navigate when condition is true', () => {
        render(_jsx(RedirectionGuard, { condition: true, isLoading: false, route: "/test", children: _jsx("div", { children: "Test Child" }) }));
        expect(Navigate).toHaveBeenCalledWith({ to: '/test' }, {});
    });
    it('should render spinner when isLoading is true', () => {
        render(_jsx(RedirectionGuard, { condition: false, isLoading: true, route: "/test", children: _jsx("div", { children: "Test Child" }) }));
        expect(screen.getByTestId('redirectionGuard_spinner')).toBeInTheDocument();
    });
    it('should render errorComponent when isError is true', () => {
        render(_jsx(RedirectionGuard, { condition: false, isLoading: false, isError: true, errorComponent: _jsx("div", { children: "Test Error" }), route: "/test", children: _jsx("div", { children: "Test Child" }) }));
        expect(screen.getByText('Test Error')).toBeInTheDocument();
        expect(Navigate).not.toHaveBeenCalled();
    });
});
