import { useState } from 'react';
import { fetchIcebergV6 } from '@ovh-ux/manager-core-api';
import { useInfiniteQuery } from '@tanstack/react-query';
/**
 * @deprecated use fetchIcebergV6 from @ovh-ux/manager-core-api
 */
export const getResourcesIcebergV6 = fetchIcebergV6;
export function useResourcesIcebergV6({ route, pageSize = 10, queryKey, defaultSorting = undefined, }) {
    const [sorting, setSorting] = useState(defaultSorting);
    const { data: dataSelected, ...rest } = useInfiniteQuery({
        initialPageParam: 1,
        queryKey: [...queryKey, pageSize, sorting],
        staleTime: Infinity,
        retry: false,
        queryFn: ({ pageParam: pageIndex }) => fetchIcebergV6({
            route,
            pageSize,
            page: pageIndex,
            sortBy: sorting?.id || null,
            sortReverse: sorting?.desc,
        }),
        getNextPageParam: (lastPage, _allPages, lastPageIndex) => {
            if (lastPage.totalCount / pageSize > lastPageIndex) {
                return lastPageIndex + 1;
            }
            return null;
        },
        select: (data) => {
            const pageIndex = data.pageParams[data.pageParams.length - 1];
            const { totalCount } = data.pages[0];
            return {
                data,
                pageIndex,
                totalCount,
                flattenData: data.pages.flatMap((page) => page.data),
            };
        },
    });
    return {
        ...(dataSelected ?? { ...dataSelected, totalCount: 0 }),
        ...rest,
        sorting,
        setSorting,
    };
}
