import { apiClient } from '@ovh-ux/manager-core-api';
import { useQuery } from '@tanstack/react-query';
export const fetchFeatureAvailabilityData = async (featureList) => {
    const result = await apiClient.aapi.get(`/feature/${featureList.join(',')}/availability`);
    const features = {};
    featureList.forEach((feature) => {
        features[feature] = feature in result.data ? result.data[feature] : false;
    });
    return features;
};
export const getFeatureAvailabilityQueryKey = (featureList) => [`feature-availability-${featureList.join('-')}`];
/**
 * @examples
 * const featureList = ['billing', 'webooo', 'web:microsoft'];
 *
 * const { data, error, isLoading } = useFeatureAvailability(featureList);
 * const isBillingAvailable = data?.billing;
 * const isWebooooAvailable = data?.webooo;
 * const isMicrosoftAvailable = data.['web:microsoft'];
 */
export const useFeatureAvailability = (featureList) => useQuery({
    queryKey: getFeatureAvailabilityQueryKey(featureList),
    queryFn: () => fetchFeatureAvailabilityData(featureList),
});
