import { apiClient } from '@ovh-ux/manager-core-api';
import { useQuery, keepPreviousData } from '@tanstack/react-query';
export const fetchAuthorizationsCheck = async ({ actions, urns, }) => {
    const { data } = await apiClient.v2.post(`/iam/authorization/check`, {
        actions,
        resourceURNs: urns,
    });
    return data;
};
export function useAuthorizationsIam({ actions, urns }) {
    const { data } = useQuery({
        queryKey: ['iam-authorization', urns, actions],
        queryFn: () => fetchAuthorizationsCheck({ actions, urns }),
        enabled: urns.length > 0 && actions.length > 0,
        placeholderData: keepPreviousData,
    });
    return data || [];
}
export function getAuthorizationCheckUrl(urn) {
    return `/iam/resource/${encodeURIComponent(urn)}/authorization/check`;
}
export const fetchAuthorizationCheck = async (actions, urn) => {
    const { data } = await apiClient.v2.post(getAuthorizationCheckUrl(urn), {
        actions,
    });
    return data;
};
export function useAuthorizationIam(actions, urn, isTrigger = true) {
    const { data, ...query } = useQuery({
        queryKey: [urn, actions],
        queryFn: () => fetchAuthorizationCheck(actions, urn),
        enabled: Boolean(urn && urn.length > 0 && actions && actions.length > 0 && isTrigger),
        placeholderData: keepPreviousData,
    });
    return {
        isAuthorized: !!data?.authorizedActions &&
            actions.every((action) => data?.authorizedActions?.includes(action)),
        data,
        ...query,
    };
}
