import { useMemo } from 'react';
import { v6 } from '@ovh-ux/manager-core-api';
import { useQuery } from '@tanstack/react-query';
export const getAggregatedNetwork = async (projectId) => {
    const { data } = await v6.get(`/cloud/project/${projectId}/aggregated/network`);
    return data;
};
export const getAggregatedPrivateNetworksQueryKey = (projectId) => [
    'aggregated-network',
    projectId,
];
export const useAggregatedPrivateNetworks = (projectId, customerRegions) => {
    return useQuery({
        queryKey: getAggregatedPrivateNetworksQueryKey(projectId),
        queryFn: () => getAggregatedNetwork(projectId),
        enabled: customerRegions?.length > 0,
        select: (data) => {
            const privateNetworks = {};
            const localZones = customerRegions?.filter(({ type }) => type.includes('localzone')) || [];
            data.resources?.forEach((network) => {
                if (network.visibility === 'private' &&
                    !localZones?.some((region) => region.name === network.region)) {
                    if (!privateNetworks[network.vlanId]) {
                        const { id, region, ...rest } = network;
                        privateNetworks[network.vlanId] = {
                            ...rest,
                            region,
                            subnets: [{ region, networkId: id }],
                        };
                    }
                    else {
                        const { id, region } = network;
                        privateNetworks[network.vlanId].subnets.push({
                            region,
                            networkId: id,
                        });
                    }
                }
            });
            return Object.values(privateNetworks);
        },
    });
};
export const useAggregatedPrivateNetworksRegions = (projectId, customerRegions) => {
    const privateNetworksQuery = useAggregatedPrivateNetworks(projectId, customerRegions);
    const { data } = privateNetworksQuery;
    return {
        ...privateNetworksQuery,
        data: useMemo(() => Array.from(new Set(data?.reduce((result, network) => result.concat(network.subnets.map(({ region }) => region)), []))), [data]),
    };
};
