import { jsx as _jsx } from "react/jsx-runtime";
import { QueryClient, QueryClientProvider, } from '@tanstack/react-query';
import { vitest } from 'vitest';
import { renderHook } from '@testing-library/react';
import { useProductMaintenance } from './useMaintenance';
import * as useMigrationSteins from './useMigrationSteins';
import * as useAggregatedPrivateNetworks from './useAggregatedPrivateNetworks';
import * as useProjectRegions from './useProjectRegions';
import '@testing-library/jest-dom';
const renderUseMaintenanceHook = () => {
    const queryClient = new QueryClient();
    const wrapper = ({ children }) => (_jsx(QueryClientProvider, { client: queryClient, children: children }));
    const { result } = renderHook(() => useProductMaintenance('projectId'), {
        wrapper,
    });
    return result;
};
describe('useMaintenance', () => {
    it('should return hasMaintenance with false value when useMigrationSteins return empty array', async () => {
        vitest.spyOn(useMigrationSteins, 'useMigrationSteins').mockReturnValue({
            data: [],
        });
        vitest.spyOn(useProjectRegions, 'useProjectRegions').mockReturnValue({
            data: [],
        });
        vitest
            .spyOn(useAggregatedPrivateNetworks, 'useAggregatedPrivateNetworksRegions')
            .mockReturnValue({
            data: [],
        });
        const result = renderUseMaintenanceHook();
        expect(result.current.hasMaintenance).toEqual(false);
    });
    it('should return hasMaintenance with false value when useAggregatedPrivateNetworksRegions return empty array', async () => {
        const mockSteins = [
            {
                date: 'date-1',
                zone: 'REGION-1',
                travaux: 'travaux-1',
            },
            {
                date: 'date-2',
                zone: 'REGION-2',
                travaux: 'travaux-2',
            },
        ];
        vitest.spyOn(useMigrationSteins, 'useMigrationSteins').mockReturnValue({
            data: mockSteins,
        });
        vitest
            .spyOn(useAggregatedPrivateNetworks, 'useAggregatedPrivateNetworksRegions')
            .mockReturnValue({
            data: [],
        });
        const result = renderUseMaintenanceHook();
        expect(result.current.hasMaintenance).toEqual(false);
    });
    it('should return hasMaintenance true.', async () => {
        const mockedCustomRegions = [
            {
                name: 'RN',
                type: 'RT',
                status: 'RS',
                continentCode: 'CC',
                datacenterLocation: 'DCL',
            },
        ];
        vitest.spyOn(useProjectRegions, 'useProjectRegions').mockReturnValue({
            data: mockedCustomRegions,
        });
        const mockSteins = [
            {
                date: 'date-1',
                zone: 'REGION-1',
                travaux: 'travaux-1',
            },
            {
                date: 'date-2',
                zone: 'REGION-2',
                travaux: 'travaux-2',
            },
        ];
        vitest.spyOn(useMigrationSteins, 'useMigrationSteins').mockReturnValue({
            data: mockSteins,
        });
        const mockedProjectRegions = ['REGION-1', 'REGION-2'];
        vitest
            .spyOn(useAggregatedPrivateNetworks, 'useAggregatedPrivateNetworksRegions')
            .mockReturnValue({
            data: mockedProjectRegions,
        });
        const result = renderUseMaintenanceHook();
        expect(result.current.hasMaintenance).toEqual(true);
    });
});
