import { useMutation, useQueryClient } from '@tanstack/react-query';
import { getResourceServiceId, getResourceServiceIdQueryKey, deleteService, } from '../api';
export const deleteServiceMutationKey = ['delete-service'];
export const useDeleteService = ({ onSuccess, onError, mutationKey = deleteServiceMutationKey, }) => {
    const queryClient = useQueryClient();
    const { mutate: terminateService, ...mutation } = useMutation({
        mutationKey,
        mutationFn: async ({ resourceName }) => {
            const { data } = await queryClient.fetchQuery({
                queryKey: getResourceServiceIdQueryKey({ resourceName }),
                queryFn: () => getResourceServiceId({ resourceName }),
            });
            return deleteService({ serviceId: data[0] });
        },
        onSuccess,
        onError,
    });
    return {
        terminateService,
        ...mutation,
    };
};
