import React from 'react';
import { apiClient } from '@ovh-ux/manager-core-api';
import { useQuery } from '@tanstack/react-query';
export const getDefaultQueryKey = (taskId) => [
    'manage-task',
    taskId,
];
export const useTask = ({ resourceUrl, apiVersion = 'v2', taskId, queryKey, onSuccess, onError, onFinish, refetchIntervalTime = 2000, }) => {
    const [isSuccess, setIsSuccess] = React.useState(false);
    const [isPending, setIsPending] = React.useState(false);
    const [isError, setIsError] = React.useState(false);
    const { error } = useQuery({
        staleTime: 0,
        queryKey: queryKey || getDefaultQueryKey(taskId || resourceUrl),
        queryFn: async () => {
            const url = `/${resourceUrl
                .split('/')
                .filter(Boolean)
                .concat(['task', taskId])
                .join('/')}`;
            try {
                setIsPending(true);
                const result = await apiClient[apiVersion].get(url);
                if (apiVersion === 'v2') {
                    if (result.data?.status === 'DONE') {
                        setIsPending(false);
                        setIsSuccess(true);
                        setIsError(false);
                        onSuccess?.();
                        onFinish?.();
                    }
                    if (result.data?.status === 'ERROR') {
                        setIsPending(false);
                        setIsSuccess(false);
                        setIsError(true);
                        onError?.();
                        onFinish?.();
                        throw result;
                    }
                }
                return result;
            }
            catch (err) {
                if (apiVersion === 'v6') {
                    if (err?.response?.status === 404) {
                        setIsPending(false);
                        setIsSuccess(true);
                        setIsError(false);
                        onSuccess?.();
                    }
                    else {
                        setIsPending(false);
                        setIsError(true);
                        setIsSuccess(false);
                        onError?.();
                    }
                    onFinish?.();
                }
                throw err;
            }
        },
        enabled: !!taskId,
        retry: false,
        refetchInterval: (query) => {
            if (apiVersion === 'v6') {
                return query.state.status !== 'error' ? refetchIntervalTime : undefined;
            }
            return !['DONE', 'ERROR'].includes(query.state.data?.data?.status)
                ? refetchIntervalTime
                : undefined;
        },
    });
    return {
        error,
        isError,
        isPending,
        isSuccess,
    };
};
