import { useTranslation } from 'react-i18next';
import { useMe } from './useMe';
export const ASIA_FORMAT = ['SG', 'ASIA', 'AU', 'IN'];
export const FRENCH_FORMAT = [
    'CZ',
    'ES',
    'FR',
    'GB',
    'IE',
    'IT',
    'LT',
    'MA',
    'NL',
    'PL',
    'PT',
    'TN',
];
export const GERMAN_FORMAT = ['DE', 'FI', 'SN'];
export const HOUR_IN_MONTH = 730;
export const priceToUcent = (price) => price * 100000000;
export const priceFromUcent = (price) => price / 100000000;
/**
 * Handle the conversion on the frontend side from hourly price to monthly.
 * In the future, this conversion should be handled on the backend to improve efficiency and maintainability.
 * */
export const convertHourlyPriceToMonthly = (hourlyPrice) => hourlyPrice * HOUR_IN_MONTH;
export const useCatalogPrice = (maximumFractionDigits, options) => {
    const { i18n, t } = useTranslation('order-price');
    const { me } = useMe();
    const isFrench = FRENCH_FORMAT.includes(me?.ovhSubsidiary);
    const isAsia = ASIA_FORMAT.includes(me?.ovhSubsidiary);
    const isGerman = GERMAN_FORMAT.includes(me?.ovhSubsidiary);
    const isTaxExcl = options?.exclVat || isAsia || isFrench || isGerman;
    const getTextPrice = (priceInCents) => {
        const priceToFormat = priceFromUcent(priceInCents);
        const numberFormatOptions = {
            style: 'currency',
            currency: me?.currency?.code,
            ...(maximumFractionDigits ? { maximumFractionDigits } : {}),
        };
        return me
            ? new Intl.NumberFormat(i18n.language?.replace('_', '-'), numberFormatOptions).format(priceToFormat)
            : '';
    };
    const getFormattedCatalogPrice = (price) => isTaxExcl && !options?.hideTaxLabel && !isGerman
        ? t('order_catalog_price_tax_excl_label', {
            price: getTextPrice(price),
        })
        : getTextPrice(price);
    const getFormattedHourlyCatalogPrice = (price) => `${getFormattedCatalogPrice(price)} / ${t(`order_catalog_price_interval_hour`)}`;
    const getFormattedMonthlyCatalogPrice = (price) => `${getFormattedCatalogPrice(price)} / ${t(`order_catalog_price_interval_month`)}`;
    return {
        getTextPrice,
        getFormattedCatalogPrice,
        getFormattedHourlyCatalogPrice,
        getFormattedMonthlyCatalogPrice,
    };
};
