/// <reference types="react" />
import { ColumnSort as TanstackColumnSort, PaginationState as TanstackPaginationState } from '@tanstack/react-table';
import './translations';
export type ColumnSort = TanstackColumnSort;
export type PaginationState = TanstackPaginationState;
export interface DatagridColumn<T> {
    /** unique column identifier */
    id: string;
    /** formatter function to render a column cell */
    cell: (props: T) => JSX.Element;
    /** label displayed for the column in the table */
    label: string;
    /** is the column sortable ? (defaults is true) */
    isSortable?: boolean;
}
export interface DatagridProps<T> {
    /** list of datagrid columns */
    columns: DatagridColumn<T>[];
    /** list of items (rows) to display in the table */
    items: T[];
    /** total number of items (in case of pagination) */
    totalItems: number;
    /** state of pagination (optional if no pagination is required) */
    pagination?: PaginationState;
    /** state of column sorting (optional if column sorting is not required) */
    sorting?: ColumnSort;
    /** callback to handle pagination change events (optional if no pagination is required) */
    onPaginationChange?: (pagination: PaginationState) => void;
    /** callback to handle column sorting change events (optional if column sorting is not required) */
    onSortChange?: any;
    /** option to add custom CSS class */
    className?: string;
    /** option to adjust content on the left */
    contentAlignLeft?: boolean;
    /** boolean to display load more button */
    hasNextPage?: boolean;
    /** callback when click on load more button */
    onFetchNextPage?: any;
    /** Enables manual sorting for the table */
    manualSorting?: boolean;
    /** Enables manual pagination */
    manualPagination?: boolean;
    /** If provided, this function will be called with an updaterFn when state.sorting changes. */
    /** setSorting?: OnChangeFn<SortingState>; */
    /** label displayed if there is no item in the datagrid */
    noResultLabel?: string;
}
export declare const Datagrid: <T>({ columns, items, totalItems, pagination, sorting, className, onPaginationChange, onSortChange, contentAlignLeft, hasNextPage, onFetchNextPage, manualSorting, manualPagination, noResultLabel, }: DatagridProps<T>) => import("react/jsx-runtime").JSX.Element;
